type_inference Package
======================

:mod:`type_inference` Package
-----------------------------

.. automodule:: numba.type_inference
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`deferred` Module
----------------------

.. automodule:: numba.type_inference.deferred
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`infer` Module
-------------------

.. automodule:: numba.type_inference.infer
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`infer_call` Module
------------------------

.. automodule:: numba.type_inference.infer_call
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`module_type_inference` Module
-----------------------------------

.. automodule:: numba.type_inference.module_type_inference
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.type_inference.modules
    numba.type_inference.tests

